@@ -34,7 +34,11 @@
 #include <stdio.h>
 #include <string.h>
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
 #include "config.h"
+#endif
 
 #ifdef SPATIALITE_AMALGAMATION
 #include <spatialite/sqlite3.h>
@@ -92,16 +96,29 @@ spatialite_autocreate (sqlite3 * db)
 	return;
 
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata(1)");
+    strcpy (sql, "SELECT InitSpatialMetadataFull(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
-	  fprintf (stderr, "InitSpatialMetadata() error: %s\n", err_msg);
+	  fprintf (stderr, "InitSpatialMetadataFull() error: %s\n", err_msg);
 	  sqlite3_free (err_msg);
 	  return;
       }
 }
 
+static void
+do_version ()
+{
+/* printing version infos */
+	fprintf( stderr, "\nVersion infos\n");
+	fprintf( stderr, "===========================================\n");
+    fprintf (stderr, "spatialite_dxf: %s\n", VERSION);
+	fprintf (stderr, "target CPU ...: %s\n", spatialite_target_cpu ());
+    fprintf (stderr, "libspatialite : %s\n", spatialite_version ());
+    fprintf (stderr, "libsqlite3 ...: %s\n", sqlite3_libversion ());
+    fprintf (stderr, "\n");
+}
+
 static void
 do_help ()
 {
@@ -111,6 +128,7 @@ do_help ()
 	     "==============================================================\n");
     fprintf (stderr,
 	     "-h or --help                    print this help message\n");
+    fprintf (stderr, "-v or --version                 print version infos\n");
     fprintf (stderr,
 	     "-d or --db-path  pathname       the SpatiaLite DB path\n");
     fprintf (stderr, "-x or --dxf-path pathname       the input DXF path\n\n");
@@ -217,6 +235,12 @@ main (int argc, char *argv[])
 		do_help ();
 		return -1;
 	    }
+	  if (strcasecmp (argv[i], "--version") == 0
+	      || strcmp (argv[i], "-v") == 0)
+	    {
+		do_version ();
+		return -1;
+	    }
 	  if (strcasecmp (argv[i], "--db-path") == 0)
 	    {
 		next_arg = ARG_DB_PATH;
