@@ -591,6 +591,8 @@ end1_tag (void *data, const char *el)
 	  *(params->CharData + params->CharDataLen) = '\0';
 	  column_name (params, el);
       }
+    *(params->CharData) = '\0';
+    params->CharDataLen = 0;
 }
 
 static void
@@ -1259,6 +1261,8 @@ end2_tag (void *data, const char *el)
 	parse_coords_1 (params);
     if (strcasecmp (el, "gml:posList") == 0 || strcasecmp (el, "gml:pos") == 0)
 	parse_coords_2 (params);
+    *(params->CharData) = '\0';
+    params->CharDataLen = 0;
 }
 
 static void
@@ -1292,11 +1296,11 @@ spatialite_autocreate (sqlite3 * db)
 	return;
 
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata(1)");
+    strcpy (sql, "SELECT InitSpatialMetadataFull(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
-	  fprintf (stderr, "InitSpatialMetadata() error: %s\n", err_msg);
+	  fprintf (stderr, "InitSpatialMetadataFull() error: %s\n", err_msg);
 	  sqlite3_free (err_msg);
 	  return;
       }
@@ -1577,6 +1581,23 @@ free_columns (struct gml_params *params)
     clean_geometry (params);
 }
 
+static void
+do_version ()
+{
+/* printing version infos */
+    XML_Expat_Version expat;
+	fprintf( stderr, "\nVersion infos\n");
+	fprintf( stderr, "===========================================\n");
+    fprintf (stderr, "spatialite_gml: %s\n", VERSION);
+	fprintf (stderr, "target CPU ...: %s\n", spatialite_target_cpu ());
+    fprintf (stderr, "libspatialite : %s\n", spatialite_version ());
+    fprintf (stderr, "libsqlite3 ...: %s\n", sqlite3_libversion ());
+    expat = XML_ExpatVersionInfo ();
+    fprintf (stderr, "libexpat .....: %d.%d.%d\n", expat.major, expat.minor,
+	     expat.micro);
+    fprintf (stderr, "\n");
+}
+
 static void
 do_help ()
 {
@@ -1586,6 +1607,7 @@ do_help ()
 	     "==============================================================\n");
     fprintf (stderr,
 	     "-h or --help                    print this help message\n");
+    fprintf (stderr, "-v or --version                 print version infos\n");
     fprintf (stderr, "-g or --gml-path pathname       the GML-XML file path\n");
     fprintf (stderr,
 	     "-d or --db-path     pathname    the SpatiaLite DB path\n\n");
@@ -1640,6 +1662,7 @@ main (int argc, char *argv[])
     params.CharDataStep = 65536;
     params.CharDataMax = params.CharDataStep;
     params.CharData = malloc (params.CharDataStep);
+    params.CharDataLen = 0;
 
     for (i = 1; i < argc; i++)
       {
@@ -1667,6 +1690,12 @@ main (int argc, char *argv[])
 		do_help ();
 		return -1;
 	    }
+	  if (strcasecmp (argv[i], "--version") == 0
+	      || strcmp (argv[i], "-v") == 0)
+	    {
+		do_version ();
+		return -1;
+	    }
 	  if (strcmp (argv[i], "-g") == 0)
 	    {
 		next_arg = ARG_GML_PATH;
