@@ -1504,11 +1504,11 @@ spatialite_autocreate (sqlite3 * db)
     if (count > 0)
 	return;
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata(1)");
+    strcpy (sql, "SELECT InitSpatialMetadataFull(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
-	  fprintf (stderr, "InitSpatialMetadata() error: %s\n", err_msg);
+	  fprintf (stderr, "InitSpatialMetadataFull() error: %s\n", err_msg);
 	  sqlite3_free (err_msg);
 	  return;
       }
@@ -2218,7 +2218,7 @@ print_template (const char *template_path, int railways)
     fprintf (out, "#\n");
     fprintf (out, "# - tokens are delimited by colons ':'\n");
     fprintf (out, "# - the second token represents the Road Class-name\n");
-    fprintf (out, "#   [no name, i.e. '::' identifies the defaul value\n");
+    fprintf (out, "#   [no name, i.e. '::' identifies the default value\n");
     fprintf (out, "#   to be applied when no specific class match is found]\n");
     fprintf (out, "# - the third token represents the corresponding speed\n");
     fprintf (out, "#   [expressed in Km/h]\n");
@@ -2242,6 +2242,22 @@ print_template (const char *template_path, int railways)
     return 1;
 }
 
+static void
+do_version ()
+{
+/* printing version infos */
+	fprintf( stderr, "\nVersion infos\n");
+	fprintf( stderr, "===========================================\n");
+    fprintf (stderr, "spatialite_osm_net: %s\n", VERSION);
+	fprintf (stderr, "target CPU .......: %s\n", spatialite_target_cpu ());
+    fprintf (stderr, "libspatialite ....: %s\n", spatialite_version ());
+    fprintf (stderr, "libsqlite3 .......: %s\n", sqlite3_libversion ());
+    fprintf (stderr, "libreadosm .......: %s\n", readosm_version ());
+    fprintf (stderr, "libexpat .........: %s\n", readosm_expat_version ());
+    fprintf (stderr, "zlib .............: %s\n", readosm_zlib_version ());
+    fprintf (stderr, "\n");
+}
+
 static void
 do_help ()
 {
@@ -2251,6 +2267,7 @@ do_help ()
 	     "==============================================================\n");
     fprintf (stderr,
 	     "-h or --help                    print this help message\n");
+    fprintf (stderr, "-v or --version                 print version infos\n");
     fprintf (stderr, "-o or --osm-path pathname       the OSM-XML file path\n");
     fprintf (stderr,
 	     "                 both OSM-XML (*.osm) and OSM-ProtoBuf\n");
@@ -2259,7 +2276,7 @@ do_help ()
     fprintf (stderr,
 	     "-d or --db-path  pathname       the SpatiaLite DB path\n");
     fprintf (stderr,
-	     "-T or --table    table_name     the db table to be feeded\n\n");
+	     "-T or --table    table_name     the db table to be fed\n\n");
     fprintf (stderr, "you can specify the following options as well\n");
     fprintf (stderr,
 	     "-cs or --cache-size    num      DB cache size (how many pages)\n");
@@ -2350,6 +2367,12 @@ main (int argc, char *argv[])
 		do_help ();
 		return -1;
 	    }
+	  if (strcasecmp (argv[i], "--version") == 0
+	      || strcmp (argv[i], "-v") == 0)
+	    {
+		do_version ();
+		return -1;
+	    }
 	  if (strcmp (argv[i], "-o") == 0)
 	    {
 		next_arg = ARG_OSM_PATH;
