@@ -620,11 +620,11 @@ spatialite_autocreate (sqlite3 * db)
 	return;
 
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata(1)");
+    strcpy (sql, "SELECT InitSpatialMetadataFull(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
-	  fprintf (stderr, "InitSpatialMetadata() error: %s\n", err_msg);
+	  fprintf (stderr, "InitSpatialMetadataFull() error: %s\n", err_msg);
 	  sqlite3_free (err_msg);
 	  return;
       }
@@ -934,6 +934,22 @@ open_db (const char *path, sqlite3 ** handle, int cache_size, void *cache)
     return;
 }
 
+static void
+do_version ()
+{
+/* printing version infos */
+	fprintf( stderr, "\nVersion infos\n");
+	fprintf( stderr, "===========================================\n");
+    fprintf (stderr, "spatialite_osm_raw: %s\n", VERSION);
+	fprintf (stderr, "target CPU .......: %s\n", spatialite_target_cpu ());
+    fprintf (stderr, "libspatialite ....: %s\n", spatialite_version ());
+    fprintf (stderr, "libsqlite3 .......: %s\n", sqlite3_libversion ());
+    fprintf (stderr, "libreadosm .......: %s\n", readosm_version ());
+    fprintf (stderr, "libexpat .........: %s\n", readosm_expat_version ());
+    fprintf (stderr, "zlib .............: %s\n", readosm_zlib_version ());
+    fprintf (stderr, "\n");
+}
+
 static void
 do_help ()
 {
@@ -943,6 +959,7 @@ do_help ()
 	     "==============================================================\n");
     fprintf (stderr,
 	     "-h or --help                    print this help message\n");
+    fprintf (stderr, "-v or --version                 print version infos\n");
     fprintf (stderr, "-o or --osm-path pathname       the OSM-file path\n");
     fprintf (stderr,
 	     "                 both OSM-XML (*.osm) and OSM-ProtoBuf\n");
@@ -1021,6 +1038,12 @@ main (int argc, char *argv[])
 		do_help ();
 		return -1;
 	    }
+	  if (strcasecmp (argv[i], "--version") == 0
+	      || strcmp (argv[i], "-v") == 0)
+	    {
+		do_version ();
+		return -1;
+	    }
 	  if (strcmp (argv[i], "-o") == 0)
 	    {
 		next_arg = ARG_OSM_PATH;
