@@ -97,11 +97,11 @@ spatialite_autocreate (sqlite3 * db)
 	return;
 
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata(1)");
+    strcpy (sql, "SELECT InitSpatialMetadataFull(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
-	  fprintf (stderr, "InitSpatialMetadata() error: %s\n", err_msg);
+	  fprintf (stderr, "InitSpatialMetadataFull() error: %s\n", err_msg);
 	  sqlite3_free (err_msg);
 	  return;
       }
@@ -229,6 +229,19 @@ do_export (char *db_path, char *shp_path, char *table, char *column,
     spatialite_cleanup_ex (cache);
 }
 
+static void
+do_version ()
+{
+/* printing version infos */
+	fprintf( stderr, "\nVersion infos\n");
+	fprintf( stderr, "===========================================\n");
+    fprintf (stderr, "exif_loader .: %s\n", VERSION);
+	fprintf (stderr, "target CPU ..: %s\n", spatialite_target_cpu ());
+    fprintf (stderr, "libspatialite: %s\n", spatialite_version ());
+    fprintf (stderr, "libsqlite3 ..: %s\n", sqlite3_libversion ());
+    fprintf (stderr, "\n");
+}
+
 static void
 do_help ()
 {
@@ -240,6 +253,7 @@ do_help ()
     fprintf (stderr, "------------------------------------\n");
     fprintf (stderr,
 	     "-h or --help                      print this help message\n");
+    fprintf (stderr, "-v or --version                   print version infos\n");
     fprintf (stderr,
 	     "-i or --import                    import [CSV/TXT, DBF or SHP]\n");
     fprintf (stderr,
@@ -337,6 +351,12 @@ main (int argc, char *argv[])
 		do_help ();
 		return -1;
 	    }
+	  if (strcasecmp (argv[i], "--version") == 0
+	      || strcmp (argv[i], "-v") == 0)
+	    {
+		do_version ();
+		return -1;
+	    }
 	  if (strcasecmp (argv[i], "--shapefile") == 0)
 	    {
 		next_arg = ARG_SHP;
