@@ -44,7 +44,11 @@ Regione Toscana - Settore Sistema Informativo Territoriale ed Ambientale
 #include <stdio.h>
 #include <string.h>
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
 #include "config.h"
+#endif
 
 #ifdef SPATIALITE_AMALGAMATION
 #include <spatialite/sqlite3.h>
@@ -923,6 +927,19 @@ open_db (const char *path, sqlite3 ** handle, int cache_size, void *cache)
     return;
 }
 
+static void
+do_version ()
+{
+/* printing version infos */
+	fprintf( stderr, "\nVersion infos\n");
+	fprintf( stderr, "===========================================\n");
+    fprintf (stderr, "spatialite_xml_print: %s\n", VERSION);
+	fprintf (stderr, "target CPU .........: %s\n", spatialite_target_cpu ());
+    fprintf (stderr, "libspatialite ......: %s\n", spatialite_version ());
+    fprintf (stderr, "libsqlite3 .........: %s\n", sqlite3_libversion ());
+    fprintf (stderr, "\n");
+}
+
 static void
 do_help ()
 {
@@ -932,6 +949,7 @@ do_help ()
 	     "==============================================================\n");
     fprintf (stderr,
 	     "-h or --help                    print this help message\n");
+    fprintf (stderr, "-v or --version                 print version infos\n");
     fprintf (stderr,
 	     "-d or --db-path     pathname    the SpatiaLite DB [INPUT] path\n\n");
     fprintf (stderr,
@@ -983,6 +1001,12 @@ main (int argc, char *argv[])
 		do_help ();
 		return -1;
 	    }
+	  if (strcasecmp (argv[i], "--version") == 0
+	      || strcmp (argv[i], "-v") == 0)
+	    {
+		do_version ();
+		return -1;
+	    }
 	  if (strcmp (argv[i], "-x") == 0)
 	    {
 		next_arg = ARG_XML_PATH;
